@@ -2,8 +2,9 @@ from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
 from model_utils.models import TimeStampedModel, StatusModel, TimeFramedModel
+from model_utils.tracker import ModelTracker
 from model_utils.managers import QueryManager, InheritanceManager, PassThroughManager
-from model_utils.fields import SplitField, MonitorField
+from model_utils.fields import SplitField, MonitorField, StatusField
 from model_utils import Choices
 
 
@@ -29,6 +30,9 @@ class InheritanceManagerTestChild1(InheritanceManagerTestParent):
     pass
 
 
+class InheritanceManagerTestGrandChild1(InheritanceManagerTestChild1):
+    text_field = models.TextField()
+
 
 class InheritanceManagerTestChild2(InheritanceManagerTestParent):
     non_related_field_using_descriptor_2 = models.FileField(upload_to="test")
@@ -215,3 +219,35 @@ class Spot(models.Model):
     owner = models.ForeignKey(Dude, related_name='spots_owned')
 
     objects = PassThroughManager.for_queryset_class(SpotQuerySet)()
+
+
+class Tracked(models.Model):
+    name = models.CharField(max_length=20)
+    number = models.IntegerField()
+
+    tracker = ModelTracker()
+
+
+class TrackedNotDefault(models.Model):
+    name = models.CharField(max_length=20)
+    number = models.IntegerField()
+
+    name_tracker = ModelTracker(fields=['name'])
+
+
+class TrackedMultiple(models.Model):
+    name = models.CharField(max_length=20)
+    number = models.IntegerField()
+
+    name_tracker = ModelTracker(fields=['name'])
+    number_tracker = ModelTracker(fields=['number'])
+
+
+class StatusFieldDefaultFilled(models.Model):
+    STATUS = Choices((0, "no", "No"), (1, "yes", "Yes"))
+    status = StatusField(default=STATUS.yes)
+
+
+class StatusFieldDefaultNotFilled(models.Model):
+    STATUS = Choices((0, "no", "No"), (1, "yes", "Yes"))
+    status = StatusField()
